@@ -1,6 +1,7 @@
 import configparser
 from datetime import date
 import os
+import shutil
 
 import audeer
 
@@ -13,19 +14,27 @@ author = config['metadata']['author']
 copyright = f'2021-{date.today().year} audEERING GmbH'
 project = config['metadata']['name']
 version = audeer.git_repo_version()
-title = f'{project} Documentation'
+title = 'Documentation'
 
 
 # General -----------------------------------------------------------------
 master_doc = 'index'
-extensions = []
 source_suffix = '.rst'
 exclude_patterns = ['_build', 'Thumbs.db', '.DS_Store', '**.ipynb_checkpoints']
+exclude_patterns = [
+    'api-src',
+    'build',
+    'tests',
+    'Thumbs.db',
+    '.DS_Store',
+]
+templates_path = ['_templates']
 pygments_style = None
 extensions = [
     'jupyter_sphinx',  # executing code blocks
     'sphinx.ext.autodoc',
     'sphinx.ext.napoleon',  # support for Google-style docstrings
+    'sphinx.ext.autosummary',
     'sphinx.ext.viewcode',
     'sphinx.ext.intersphinx',
     'sphinx.ext.autosectionlabel',
@@ -60,6 +69,11 @@ linkcheck_ignore = [
     'https://sphinx-doc.org',
 ]
 
+# Disable auto-generation of TOC entries in the API
+# https://github.com/sphinx-doc/sphinx/issues/6316
+toc_object_entries = False
+
+
 # HTML --------------------------------------------------------------------
 html_theme = 'sphinx_audeering_theme'
 html_theme_options = {
@@ -72,3 +86,15 @@ html_context = {
 }
 html_title = title
 html_static_path = ['_static']
+
+
+# Copy API (sub-)module RST files to docs/api/ folder ---------------------
+audeer.rmdir('api')
+audeer.mkdir('api')
+api_src_files = audeer.list_file_names('api-src')
+api_dst_files = [
+    audeer.path('api', os.path.basename(src_file))
+    for src_file in api_src_files
+]
+for src_file, dst_file in zip(api_src_files, api_dst_files):
+    shutil.copyfile(src_file, dst_file)
